@@ -1,46 +1,44 @@
 import logging
-import keyring
 import os
 import pickle
 import sys
 import time
 
+# cli specific imports
 from .ui_helpers import _options, app_header, format_msg
-from .utils import (get_correct_answer, path_fixer, SetupConfig,
-                    install_check, ask_yes_no, password_hasher)
-
+from .utils import get_correct_answer, path_fixer, SetupConfig
+# framework stuff
 from not_so_tuf import NotSoTuf
 from not_so_tuf.package_handler import PackageHandler
 from not_so_tuf.key_handler import KeyHandler
 
-
 log = logging.getLogger()
 log.setLevel(logging.DEBUG)
-fh_formatter = logging.Formatter('%(asctime)s - %(name)-26s -  %(levelname)-8s -> %(message)s')
-ch_formatter = logging.Formatter('%(name)-10s: %(levelname)-8s -> %(message)s')
+format_str = '%(asctime)s - %(name)-26s -  %(levelname)-8s -> %(message)s'
+fh_formatter = logging.Formatter(format_str)
 fh = logging.FileHandler('nst.log', mode='wa')
 fh.setFormatter(fh_formatter)
-
-ch = logging.StreamHandler()
-fh.setLevel(logging.DEBUG)
-ch.setLevel(logging.INFO)
-ch.setFormatter(ch_formatter)
-fh.setFormatter(fh_formatter)
-log.addHandler(ch)
+fh.setLevel(logging.INFO)
 log.addHandler(fh)
 
+
 class Ui(object):
 
     def __init__(self):
         if sys.platform == 'win32':
+            log.info('Working on windows')
             self._clear = 'cls'
         else:
+            log.info('Working on Unix')
             self._clear = 'clear'
         try:
+            log.info('Loading config file...')
             self.config = self.load_config()
+            log.debug('Loaded config.data file')
         except:
+            log.warning('Config.data not found.')
             self.config = SetupConfig()
-        self.nst = NotSoTuf(__name__)
+        self.nst = NotSoTuf(__name__, self.config)
 
     def main(self):
         self.cwd = os.getcwd()
@@ -161,6 +159,8 @@ class Ui(object):
 
     def keys(self):
         options = [('Show Public Key', self.show_public_key),
+                   ('Make Decrypted copy of Private Key',
+                    self.private_key_copy),
                    ('Go Back', self.main)]
                    # ('Replace Keys', self.main), ('Go Back', self.main)]
         print app_header('Keys')
@@ -170,7 +170,14 @@ class Ui(object):
     def show_public_key(self):
         key_handler = KeyHandler(self.nst)
         key_handler.print_public_key()
-        raw_input('Press enter to continue')
+        raw_input(format_msg('Press enter to continue'))
+        self.keys()
+
+    def private_key_copy(self):
+        key_handler = KeyHandler(self.nst)
+        key_handler.copy_decrypted_private_key()
+        msg = 'Private key decrypted. Press enter to continue'
+        raw_input(format_msg(msg))
         self.keys()
 
     def replace_keys(self):
@@ -186,52 +193,8 @@ class Ui(object):
         sys.exit()
 
     def start(self):
-        # self.login()
         self.main()
 
-    def login(self):
-        while 1:
-            print app_header('Login')
-            if install_check() is False:
-                ans = ask_yes_no('Confirm Initial Setup', default='no')
-                if ans is False:
-                    print "Seem like someone tampered with your computer\n\n"
-                    raw_input('Press enter to continue')
-                    continue
-                print app_header('Create Account')
-                username = get_correct_answer('Enter a username',
-                                              required=True)
-                password = get_correct_answer('Enter a password',
-                                              required=True, password=True,
-                                              create_account=True)
-
-                password_check = keyring.get_password('Not So TUF', username)
-                if password_check is None:
-                    hashed_password = password_hasher(password)
-                    del password
-                    keyring.set_password('Not So TUF', username, hashed_password)
-                    del hashed_password
-            else:
-                print app_header('Login')
-                while 1:
-                    username = get_correct_answer('Username', required=True)
-                    keychain_password = keyring.get_password('Not So TUF',
-                                                             username)
-                    if keychain_password is None:
-                        print 'Not a valid user\n\n'
-                        raw_input('Press enter to continue')
-                        continue
-                    break
-                while 1:
-                    password = get_correct_answer('Password', required=True,
-                                                  password=True)
-                    if password_hasher(password) != keychain_password:
-                        print 'Invalid Password\n\n'
-                        raw_input('Press enter to continue')
-                        continue
-                    break
-                break
-
 
 def main():
     ui = Ui()
