@@ -56,17 +56,6 @@ class SetupConfig(object):
         self.PUBLIC_KEY_NAME = name + '.pub'
 
 
-def path_fixer(path):
-    # Removing ' & " in case user used them
-    # for path with spaces
-    path.replace("'", "")
-    path.replace('"', '')
-
-    # Correcting the path with spaces to work
-    # without quotes
-    path.replace (' ', '\ ')
-
-
 def get_correct_answer(question, default=None, required=False,
                        password=False, create_account=False):
     while 1:
@@ -124,30 +113,15 @@ def ask_yes_no(question, default='no'):
             print '\n\n\n\n'
 
 
-def install_check():
-    user = os.path.expanduser('~')
-    if sys.platform != 'win32':
-        path = os.path.join(user, '.not_so_tuf')
-    else:
-        path = os.path.join(user, 'AppData', 'Roaming', 'not_so_tuf')
-    if not os.path.exists(path):
-        os.mkdir(path)
-        return False
-    return True
+def path_fixer(path):
+    # Removing ' & " in case user used them
+    # for path with spaces
+    path.replace("'", "")
+    path.replace('"', '')
 
-if sys.platform == 'win32':
-    clear = 'cls'
-    settings_dir = os.path.join(user, 'not_so_tuf')
-else:
-    clear = 'clear'
-    settings_dir = os.path.join(user, '.not_so_tuf')
-
-
-def password_hasher(x):
-    digest = sha_digest(x)
-    for d in range(0, 100001):
-        digest = sha_digest(digest)
-    return digest
+    # Correcting the path with spaces to work
+    # without quotes
+    return path.replace(' ', '\ ')
 
 
 def sha_digest(data):
