@@ -77,9 +77,7 @@ class Config(dict):
         super(Config, self).__init__(defaults or {})
 
     def from_object(self, obj):
-        """Updates the values from the given object.:
-
-        -   an actual object reference: that object is used directly
+        """Updates the values from the given object
 
         Args:
             obj (instance): Object with config attributes
