@@ -63,9 +63,10 @@ class Client(object):
 
         Returns:
             (bool) Meanings::
-                True -- If successful update
 
-                False -- If unsuccessful update
+                True - Update Successful
+
+                False - Update Failed
         """
         if not self.verified:
             log.error('Version file not verified')
@@ -93,9 +94,9 @@ class Client(object):
         Returns:
             (bool) Meanings::
 
-                True -- either already up to date of patch successful
+                True - Either already up to date or patched successful
 
-                False -- either failed to patch or no base binary to patch
+                False - Either failed to patch or no base binary to patch
 
         """
         filename = self.json_data['y_data'][name][version]['filename']
@@ -130,9 +131,9 @@ class Client(object):
         Returns:
             (bool) Meanings::
 
-                True -- If full update was successful
+                True - Update Successful
 
-                False -- If full update was unsuccessful
+                False - Update Failed
         """
         # Takes resource name and current installed version number
         #
