@@ -12,7 +12,7 @@ except ImportError:
     PATCH_SUPPORT = False
 
 from not_so_tuf import PackageHandlerError
-from .utils import ChDir, ask_yes_no
+from .utils import ChDir, ask_yes_no, _get_package_hashes
 
 log = logging.getLogger(__name__)
 
@@ -57,8 +57,9 @@ class PackageHandler(object):
         self.deploy_dir = os.path.join(self.data_dir, 'deploy')
         self.new_dir = os.path.join(self.data_dir, 'new')
         self.json_data = None
-        self.supported_extensions = ['.zip', '.bz2', '.gz', '.dmg', '.7z',
-                                     '.bin', '.iso', '.dat']
+        # seems to produce the best diffs.
+        # ToDo: Run more tests to know for sure
+        self.supported_extensions = ['.zip']
         self.package_manifest = []
 
     def setup(self):
@@ -148,9 +149,10 @@ class PackageHandler(object):
                         shutil.move(p['real_name'], version_path)
                     else:
                         continue
-                shutil.move(p['real_name'], version_path)
-                log.debug('Moving {} to {}'.format(p['real_name'],
-                                                   version_path))
+                else:
+                    shutil.move(p['real_name'], version_path)
+                    log.debug('Moving {} to {}'.format(p['real_name'],
+                                                       version_path))
 
         with ChDir(self.data_dir):
             shutil.copy('version.json', self.deploy_dir)
@@ -250,21 +252,6 @@ class PackageHandler(object):
             else:
                 self.json_data['y_data'][name][version] = info
 
-    def _get_package_hashes(self, package):
-        """Get hash of provided package
-
-        Args:
-            package (str): Package name to get hash for
-
-        Returns:
-            (str) md5 hash
-        """
-        log.info('Getting package hashes')
-        with open(package, 'rb') as f:
-            _hash = hashlib.md5(f.read()).hexdigest()
-            log.debug('Hash for file {}: {}'.format(package, _hash))
-        return _hash
-
     def _get_package_list(self):
         """Adds compatible packages to internal package manifest
         for futher processing
@@ -282,7 +269,7 @@ class PackageHandler(object):
                 p_version = self._get_version_number(p)
                 p_name = self._remove_version_number(p)
                 p_name = self._remove_ext(p_name)
-                _hash = self._get_package_hashes(p)
+                _hash = _get_package_hashes(p)
                 log.debug('Found new update {}'.format(p_name))
                 package_info = {'real_name': p,
                                 'name': p_name,
@@ -292,7 +279,7 @@ class PackageHandler(object):
                 path = self._check_make_patch(p_name, p_version)
                 if self.patch_support and path is not None:
                     patch_name = self._make_patch(path[0], p, p_name, path[1])
-                    patch_hash = self._get_package_hashes(patch_name)
+                    patch_hash = _get_package_hashes(patch_name)
                     package_info['patch_name'] = patch_name
                     package_info['patch_md5'] = patch_hash
                 self.package_manifest.append(package_info)
@@ -309,9 +296,9 @@ class PackageHandler(object):
         Returns:
             (tuple) Meaning::
 
-                None -- No src binary to make patch from
+                None - No src binary to make patch from
 
-                Tuple -- (path to source file, patch number)
+                Tuple - (path to source file, patch number)
         """
         data_dir = os.path.join(self.files_dir, name)
         if os.path.exists(data_dir):
@@ -329,7 +316,9 @@ class PackageHandler(object):
                     return None
             version_dir = os.path.join(data_dir, highest_version)
             with ChDir(version_dir):
-                files = os.listdir(os.getcwd())
+                files = self._remove_hidden_stuff_mac(os.listdir(os.getcwd()))
+                if len(files) == 0:
+                    return None
                 for f in files:
                     if highest_version in f:
                         src_file_path = os.path.abspath(f)
