@@ -19,7 +19,7 @@ class FileCrypt(object):
         filename (str): The name of the file to encrypt
     """
 
-    def __init__(self, filename):
+    def __init__(self, filename=None):
         self.filename = filename
         self.enc_filename = filename + '.enc'
         self.filenames = None
@@ -83,9 +83,9 @@ def ask_yes_no(question, default='no'):
     Returns:
         bool. Meaning::
 
-            True -- Answer is  yes
+            True - Answer is  yes
 
-            Fasle -- Answer is no
+            False - Answer is no
     """
     default = default.lower()
     yes = ['yes', 'ye', 'y']
@@ -142,3 +142,21 @@ def rsa_verify(message, signature, key):
     if signature != hashlib.sha256(message).digest():
         return False
     return True
+
+
+def _get_package_hashes(filename):
+        """Get hash of provided file
+
+        Args:
+            package (str): File name to get hash for
+
+        Returns:
+            (str) md5 hash
+        """
+        log.info('Getting package hashes')
+        with open(filename, 'rb') as f:
+            print filename
+            print os.getcwd()
+            _hash = hashlib.md5(f.read()).hexdigest()
+            log.debug('Hash for file {}: {}'.format(filename, _hash))
+        return _hash
